@@ -1,7 +1,16 @@
+#' @import utils
+#'
+.onLoad <- function(libname, pkgname) {
+  assign("s", NULL, envir=parent.env(environment()))
+  globalVariables("s")
+}
+
 #' @import rscala
 #' @import commonsMath
 #'
-.onLoad <- function(libname, pkgname) {
+scalaEnsure <- function() {
+  if ( ! is.null(s) ) return()
+  commonsMath:::.packageName   # So CRAN checks recognize that its being used.
   s <- scala("commonsMath")
   scalaLazy(function(s) s + '
     import org.ddahl.sdols._
@@ -29,10 +38,13 @@
   ')
   scalaPushRegister(scalaPush.clustering,"clustering",s)
   scalaPullRegister(scalaPull.clustering,"clustering",s)
-  assign("s",s,envir=parent.env(environment()))
+  env <- parent.env(environment())
+  # unlockBinding("s", env)
+  eval(parse(text=paste0('unlockBinding("s",env)')))
+  assign("s", s, envir=env)
+  lockBinding("s", env)
 }
 
 .onUnload <- function(libpath) {
-  close(s)
+  if ( ! is.null(s) ) close(s)
 }
-
