@@ -2,7 +2,7 @@ package org.ddahl.shallot
 
 object CrossCompatibility {
 
-  val doubleOrdering = Ordering.Double
+  val doubleOrdering = Ordering.Double.TotalOrdering
 
 }
 
