@@ -1,5 +1,4 @@
-package org.ddahl.shallot
-package parameter
+package org.ddahl.shallot.parameter
 
 import partition._
 
