@@ -3,12 +3,9 @@ package parameter
 package partition
 
 import scala.util.control.Breaks._
-import scala.collection.parallel.immutable.ParVector
 
 object MinBinder {
 
-  implicit val ordering = CrossCompatibility.doubleOrdering
-
   private def allocate[A](i: Int, partition: Partition[A], pp: PairwiseProbability) = {
     val absorbingSubset = partition.minBy(subset => {
       subset.foldLeft(0.0)((sum, k) => sum + (0.5 - pp(i, k)))
@@ -70,7 +67,7 @@ object MinBinder {
     if (parallel) {
       val nCores = Runtime.getRuntime.availableProcessors
       val size = partitions.size
-      val lists = ParVector(partitions.grouped((size / nCores) + 1).toList:_*)
+      val lists = partitions.grouped((size / nCores) + 1).toList.par
       lists.map(x => search(x, maxSubsets, maxScans, pp)).minBy(_._2)._1
     } else {
       search(partitions, maxSubsets, maxScans, pp)._1
